@@ -96,16 +96,16 @@ def sample_bondinfo():
         "frequency":Frequency.semi_annual,
         "start_basis": StartBasis.today,
         "day_count": DayCount.act_act_isma,
-        "business_day": BusinessDay.mod_following,
-        "terminate_business_day": BusinessDay.mod_following,
+        "business_day": BusinessDay.no_adjustment,
+        "terminate_business_day": BusinessDay.no_adjustment,
         "date_gen": DateGeneration.backward,
         "is_eom":  True
         }
 
     setting = BondSetting(**bondsetting)
 
-    bonddata = {"issue_date": "2021-01-05", 
-                "maturity": "2026-01-05", 
+    bonddata = {"issue_date": "2021-08-13", 
+                "maturity": "2025-08-13", 
                 "settings": setting, 
                 "coupon": 5.00,
                 "face_value": 10_000_000
